@@ -23,6 +23,14 @@
 #ifndef FILEFOLDERMODEL_H
 #define FILEFOLDERMODEL_H
 
+#include <QtGlobal>
+
+#ifdef EXIV2
+#ifdef Q_OS_WIN
+#define NOMINMAX
+#endif
+#endif
+
 #include <algorithm>
 #include <QtConcurrent/QtConcurrent>
 #include <QObject>
@@ -42,6 +50,13 @@
 #ifdef POPPLER
 #include <poppler/qt5/poppler-qt5.h>
 #endif
+#ifdef QTPDF
+#include <QtPdf>
+#endif
+
+#ifdef EXIV2
+#include <exiv2/exiv2.hpp>
+#endif
 
 class PQFileFolderModel : public QObject {
 
@@ -329,6 +344,7 @@ private:
     QString cacheAdvancedSortFolderName;
     QStringList cacheAdvancedSortFolder;
     qint64 cacheAdvancedSortLastModified;
+    bool cacheAdvancedSortAscending;
 
 private Q_SLOTS:
     void loadDataMainView();
