@@ -21,6 +21,7 @@
  **************************************************************************/
 
 #include "imageproviderthumb.h"
+#include "resolutionprovider.h"
 #include "../settings/settings.h"
 
 QQuickImageResponse *PQAsyncImageProviderThumb::requestImageResponse(const QString &url, const QSize &requestedSize) {
@@ -57,10 +58,20 @@ QQuickTextureFactory *PQAsyncImageResponseThumb::textureFactory() const {
 }
 
 void PQAsyncImageResponseThumb::run() {
+    loadImage();
+}
+
+void PQAsyncImageResponseThumb::loadImage() {
 
     QString filename = QByteArray::fromPercentEncoding(m_url.toUtf8());
     filename = filename.replace("&#39;","'");
 
+    QString filenameForChecking = filename;
+    if(filenameForChecking.contains("::PQT::"))
+        filenameForChecking = filenameForChecking.split("::PQT::").at(1);
+    if(filenameForChecking.contains("::ARC::"))
+        filenameForChecking = filenameForChecking.split("::ARC::").at(1);
+
     // Create the md5 hash for the thumbnail file
     QByteArray path = QUrl::fromLocalFile(filename).toString().toUtf8();
     QByteArray md5 = QCryptographicHash::hash(path,QCryptographicHash::Md5).toHex();
@@ -70,10 +81,9 @@ void PQAsyncImageResponseThumb::run() {
 
     // We always opt for the 256px resolution for the thumbnails,
     // as then we don't have to re-create thumbnails depending on change in settings
-    bool lookInCache = (m_requestedSize.width() == 256 && m_requestedSize.height() == 256);
 
     // If files in XDG_CACHE_HOME/thumbnails/ shall be used, then do use them
-    if(lookInCache && PQSettings::get()["thumbnailsCache"].toBool()) {
+    if(PQSettings::get()["thumbnailsCache"].toBool()) {
 
         // If there exists a thumbnail of the current file already
         if(QFile(ConfigFiles::GENERIC_CACHE_DIR() + "/thumbnails/large/" + md5 + ".png").exists()) {
@@ -85,7 +95,7 @@ void PQAsyncImageResponseThumb::run() {
             uint mtime = p.text("Thumb::MTime").trimmed().toInt();
 
             // Use image if it's up-to-date
-            if(QFileInfo(filename).lastModified().toTime_t() == mtime) {
+            if(QFileInfo(filenameForChecking).lastModified().toTime_t() == mtime) {
 
                 if(m_fixedSize) {
                     QImage fix(266, 202, QImage::Format_ARGB32);
@@ -113,12 +123,6 @@ void PQAsyncImageResponseThumb::run() {
 
     // If file wasn't loaded from file or database, then it doesn't exist yet (or isn't up-to-date anymore) and we have to create it
 
-    QString filenameForChecking = filename;
-    if(filenameForChecking.contains("::PQT::"))
-        filenameForChecking = filenameForChecking.split("::PQT::").at(1);
-    if(filenameForChecking.contains("::ARC::"))
-        filenameForChecking = filenameForChecking.split("::ARC::").at(1);
-
     // We create a temporary pointer, so that we can delete it properly afterwards
     if(!QFileInfo::exists(filenameForChecking)) {
         QString err = QCoreApplication::translate("imageprovider", "File failed to load, it does not exist!");
@@ -133,6 +137,11 @@ void PQAsyncImageResponseThumb::run() {
     QSize origSize;
     QString msg = loader->load(filename, m_requestedSize, origSize, p);
 
+    // images that are smaller than the requested size are reloaded at the original size
+    // this is VERY hacky but works for now as such small images are loaded very quickly
+    if(origSize.isValid() && origSize.width() < p.size().width() && origSize.height() < p.size().height())
+        QString msg = loader->load(filename, origSize, origSize, p);
+
     /**********************************************************/
 
     if(p.isNull() || msg != "") {
@@ -157,7 +166,7 @@ void PQAsyncImageResponseThumb::run() {
         p = p.scaled(m_requestedSize, Qt::KeepAspectRatio, Qt::SmoothTransformation);
 
     // Create file cache thumbnail
-    if(lookInCache && PQSettings::get()["thumbnailsCache"].toBool() && msg != "x") {
+    if(PQSettings::get()["thumbnailsCache"].toBool() && msg != "x") {
 
         // If the file itself wasn't read from the thumbnails folder, is not a temporary file, and if the original file isn't at thumbnail size itself
         if(!filename.startsWith(QString(ConfigFiles::GENERIC_CACHE_DIR() + "/thumbnails").toUtf8())
@@ -165,8 +174,8 @@ void PQAsyncImageResponseThumb::run() {
 
             // Set some required (and additional) meta information
             p.setText("Thumb::URI", QString("file:///%1").arg(QString(filename)));
-            p.setText("Thumb::MTime", QString("%1").arg(QFileInfo(filename).lastModified().toTime_t()));
-            QString mime = mimedb.mimeTypeForFile(filename, QMimeDatabase::MatchContent).name();
+            p.setText("Thumb::MTime", QString("%1").arg(QFileInfo(filenameForChecking).lastModified().toTime_t()));
+            QString mime = mimedb.mimeTypeForFile(filenameForChecking, QMimeDatabase::MatchContent).name();
             // this is the default mime type if no mime type is available or file cannot be found
             if(mime != "application/octet-stream")
                 p.setText("Thumb::Mimetype", mime);
