@@ -1,6 +1,6 @@
 /**************************************************************************
  **                                                                      **
- ** Copyright (C) 2011-2022 Lukas Spies                                  **
+ ** Copyright (C) 2011-2023 Lukas Spies                                  **
  ** Contact: https://photoqt.org                                         **
  **                                                                      **
  ** This file is part of PhotoQt.                                        **
@@ -21,6 +21,9 @@
  **************************************************************************/
 
 #include "loadimage_qt.h"
+#ifdef RESVG
+#include <ResvgQt.h>
+#endif
 
 PQLoadImageQt::PQLoadImageQt() {
     errormsg = "";
@@ -48,6 +51,18 @@ QImage PQLoadImageQt::load(QString filename, QSize maxSize, QSize &origSize, boo
 
     if(suffix == "svg") {
 
+#ifdef RESVG
+
+        ResvgOptions opt;
+        ResvgRenderer renderer(filename, opt);
+
+        if(maxSize.isValid())
+            return renderer.renderToImage();
+
+        return renderer.renderToImage(maxSize);
+
+#else
+
         // For reading SVG files
         QSvgRenderer svg;
         QImage svg_image;
@@ -74,6 +89,8 @@ QImage PQLoadImageQt::load(QString filename, QSize maxSize, QSize &origSize, boo
 
         return svg_image;
 
+#endif
+
     } else {
 
         // For all other supported file types
