@@ -22,6 +22,11 @@
 
 #include "handlingfiledir.h"
 
+PQHandlingFileDir::PQHandlingFileDir() {
+    animatedImageTemporaryCounter = 0;
+    animatedImagesTemporaryList.clear();
+}
+
 QString PQHandlingFileDir::cleanPath(QString path) {
 
     DBG << CURDATE << "PQHandlingFileDir::cleanPath()" << NL
@@ -45,6 +50,11 @@ QString PQHandlingFileDir::cleanPath(QString path) {
         path = path.remove(0, 13);
     else if(path.startsWith("image://thumb/"))
         path = path.remove(0, 14);
+    else if(path.startsWith("image://folderthumb/")) {
+        path = path.remove(0, 20);
+        if(path.contains(":://::"))
+            path = path.split(":://::")[0];
+    }
 
 #ifdef Q_OS_WIN
     path = QDir::cleanPath(path.replace("//", "|::::::::|"));
@@ -78,6 +88,70 @@ QString PQHandlingFileDir::copyFile(QString filename) {
 
 }
 
+bool PQHandlingFileDir::copyFileToHere(QString filename, QString targetdir) {
+
+    DBG << CURDATE << "PQHandlingFileDir::copyFileToHere()" << NL
+        << CURDATE << "** filename = " << filename.toStdString() << NL
+        << CURDATE << "** targetdir = " << targetdir.toStdString() << NL;
+
+    QFileInfo info(filename);
+    if(!info.exists())
+        return false;
+
+    QString targetFilename = QString("%1/%2").arg(targetdir).arg(info.fileName());
+    QFileInfo targetinfo(targetFilename);
+
+    // file copied to itself
+    if(targetFilename == filename)
+        return true;
+
+    if(targetinfo.exists()) {
+        QFile tf(targetFilename);
+        tf.remove();
+    }
+
+    QFile f(filename);
+    return f.copy(targetFilename);
+
+}
+
+QString PQHandlingFileDir::copyFileToCacheDir(QString filename) {
+
+    DBG << CURDATE << "PQHandlingFileDir::copyFileToTmpDir()" << NL
+        << CURDATE << "** filename = " << filename.toStdString() << NL;
+
+    QFileInfo info(filename);
+    if(!info.exists())
+        return "";
+
+    // if the image is larger than 256 MB we don't copy this
+    if(info.size() > 1024*1024*256)
+        return "";
+
+    QString targetFilename = QString("%1/%2%3.%4").arg(ConfigFiles::CACHE_DIR()).arg("temp").arg(animatedImageTemporaryCounter).arg(info.suffix());
+    QFileInfo targetinfo(targetFilename);
+
+    animatedImageTemporaryCounter = (animatedImageTemporaryCounter+1)%3;
+    if(!animatedImagesTemporaryList.contains(targetFilename))
+        animatedImagesTemporaryList.append(targetFilename);
+
+    // file copied to itself
+    if(targetFilename == filename)
+        return "";
+
+    if(targetinfo.exists()) {
+        QFile tf(targetFilename);
+        tf.remove();
+    }
+
+    QFile f(filename);
+    if(f.copy(targetFilename))
+        return targetFilename;
+
+    return "";
+
+}
+
 bool PQHandlingFileDir::deleteFile(QString filename, bool permanent) {
 
     DBG << CURDATE << "PQHandlingFileDir::deleteFile()" << NL
@@ -85,140 +159,219 @@ bool PQHandlingFileDir::deleteFile(QString filename, bool permanent) {
         << CURDATE << "** permanent = " << permanent << NL;
 
     if(permanent) {
+        QFileInfo info(filename);
+        if(info.isDir()) {
+            QDir dir(filename);
+            if(!dir.removeRecursively()) {
+                LOG << CURDATE << "PQHandlingFileDir::deleteFile(): Failed to delete folder recursively!" << NL;
+                return false;
+            }
+            return true;
+        }
         QFile file(filename);
         return file.remove();
     }
 
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 15, 0))
+#ifdef Q_OS_LINUX
+
+    // the native Qt function has some issues (at least on Linux):
+    // 1) doesn't encode path in trashinfo file
+    // 2) uses different convention for handling duplicate filenames
+    // 3) doesn't update the directorysizes file (for folders)
+    // For now, our custom implementation only supports Linux.
+    return moveFileToTrash(filename);
+
+#elif (QT_VERSION >= QT_VERSION_CHECK(5, 15, 0))
 
     QFile file(filename);
+#ifdef Q_OS_WIN
+    // we need to call moveToTrash on a different QFile object, otherwise the exists() check will return false
+    // even while the file isn't deleted as it is seen as opened by PhotoQt
+    QFile f(filename);
+    bool ret = f.moveToTrash();
+    int count = 0;
+    while(file.exists() && count < 20) {
+        QFile f(filename);
+        ret = f.moveToTrash();
+        std::this_thread::sleep_for(std::chrono::milliseconds(250));
+        ++count;
+    }
+    return ret;
+#else
     return file.moveToTrash();
+#endif
 
 #else
-#if Q_OS_WIN
+    return moveFileToTrash(filename);
+#endif
+
+}
+
+void PQHandlingFileDir::deleteTemporaryAnimatedImageFiles() {
+
+    DBG << CURDATE << "PQHandlingFileDir::deleteTemporaryAnimatedImageFiles()" << NL;
+
+    for(const auto &f : qAsConst(animatedImagesTemporaryList)) {
+        qDebug() << "deleting:" << f;
+        QFile file(f);
+        file.remove();
+    }
+
+}
+
+bool PQHandlingFileDir::moveFileToTrash(QString filename) {
+
+    DBG << CURDATE << "PQHandlingFileDir::moveFileToTrash()" << NL
+        << CURDATE << "** filename = " << filename.toStdString() << NL;
+
+#ifdef Q_OS_WIN
     QFile file(filename);
     return file.remove();
 #else
-    // The file to delete
-    QFile file(filename);
 
-    // Of course we only proceed if the file actually exists
-    if(file.exists()) {
+    QFileInfo info(filename);
 
-        // Create the meta .trashinfo file
-        QString info = "[Trash Info]\n";
-        info += "Path=" + QUrl(filename).toEncoded() + "\n";
-        info += "DeletionDate=" + QDateTime::currentDateTime().toString("yyyy-MM-ddThh:mm:ss");
+    if(!info.exists()) {
+        LOG << CURDATE << "PQHandlingFileDir::deleteFile(): ERROR: File/Folder '" << filename.toStdString() << "' doesn't exist...?" << NL;
+        return false;
+    }
 
-        // The base patzh for the Trah (files on external devices  use the external device for Trash)
-        QString baseTrash = "";
+    // Create the meta .trashinfo file
+    QString trashinfo = "[Trash Info]\n";
+    trashinfo += "Path=" + QUrl(filename).toEncoded() + "\n";
+    trashinfo += "DeletionDate=" + QDateTime::currentDateTime().toString("yyyy-MM-ddThh:mm:ss");
 
-        // If file lies in the home directory
-        if(QFileInfo(filename).absoluteFilePath().startsWith(QDir::homePath())) {
+    // The base path for the Trah (files on external devices  use the external device for Trash)
+    QString baseTrash = "";
 
-            // Set the base path and make sure all the dirs exist
-            baseTrash = ConfigFiles::GENERIC_DATA_DIR() + "/Trash/";
+    // If file lies in the home directory
+    if(QFileInfo(filename).absoluteFilePath().startsWith(QDir::homePath())) {
 
-            QDir dir;
-            dir.setPath(baseTrash);
-            if(!dir.exists()) {
-                if(!dir.mkpath(baseTrash)) {
-                    LOG << "PQHandlingFileDir::deleteFile(): ERROR: mkdir(baseTrash) failed!";
-                    return false;
-                }
-            }
-            dir.setPath(baseTrash + "files");
-            if(!dir.exists()) {
-                if(!dir.mkdir(baseTrash + "files")) {
-                    LOG << "PQHandlingFileDir::deleteFile(): ERROR: mkdir(files) failed!";
-                    return false;
-                }
-            }
-            dir.setPath(baseTrash + "info");
-            if(!dir.exists()) {
-                if(!dir.mkdir(baseTrash + "info")) {
-                    LOG << "PQHandlingFileDir::deleteFile(): ERROR: mkdir(info) failed!";
-                    return false;
-                }
-            }
-        } else {
-            // Set the base path ...
-            for(QStorageInfo &storage : QStorageInfo::mountedVolumes()) {
-                if(!storage.isReadOnly() && storage.isValid() && filename.startsWith(storage.rootPath()) &&
-                   baseTrash.length() < storage.rootPath().length()) {
-                    baseTrash = storage.rootPath();
-                }
-            }
-            baseTrash += "/" + QString("/.Trash-%1/").arg(getuid());
-            // ... and make sure all the dirs exist
-            QDir dir;
-            dir.setPath(baseTrash);
-            if(!dir.exists()) {
-                if(!dir.mkdir(baseTrash)) {
-                    LOG << "PQHandlingFileDir::deleteFile(): ERROR: mkdir(baseTrash) failed!";
-                    return false;
-                }
-            }
-            dir.setPath(baseTrash + "files");
-            if(!dir.exists()) {
-                if(!dir.mkdir(baseTrash + "files")) {
-                    LOG << "PQHandlingFileDir::deleteFile(): ERROR: mkdir(files) failed!";
-                    return false;
-                }
-            }
-            dir.setPath(baseTrash + "info");
-            if(!dir.exists()) {
-                if(!dir.mkdir(baseTrash + "info")) {
-                    LOG << "PQHandlingFileDir::deleteFile(): ERROR: mkdir(info) failed!";
-                    return false;
-                }
-            }
+        // Set the base path and make sure all the dirs exist
+        baseTrash = ConfigFiles::GENERIC_DATA_DIR() + "/Trash/";
 
-        }
-
-        // that's the new trash file
-        QString trashFile = baseTrash + "files/" + QUrl::toPercentEncoding(QFileInfo(file).fileName(),""," ");
-        QString backupTrashFile = trashFile;
-
-        // If there exists already a file with that name, we simply append the next higher number (sarting at 1)
-        QFile ensure(trashFile);
-        int j = 1;
-        while(ensure.exists()) {
-            trashFile = backupTrashFile + QString(" (%1)").arg(j++);
-            ensure.setFileName(trashFile);
-        }
-
-        // Copy the file to the Trash
-        if(file.copy(trashFile)) {
-
-            // And remove the old file
-            if(!file.remove()) {
-                LOG << CURDATE << "PQHandlingFileDir::deleteFile(): ERROR: Old file couldn't be removed!" << NL;
+        QDir dir;
+        dir.setPath(baseTrash);
+        if(!dir.exists()) {
+            if(!dir.mkpath(baseTrash)) {
+                LOG << "PQHandlingFileDir::deleteFile(): ERROR: mkdir(baseTrash) failed!";
                 return false;
             }
-
-            // Write the .trashinfo file
-            QFile i(baseTrash + "info/" + QFileInfo(trashFile).fileName() + ".trashinfo");
-            if(i.open(QIODevice::WriteOnly)) {
-                QTextStream out(&i);
-                out << info;
-                i.close();
-            } else {
-                LOG << CURDATE << "PQHandlingFileDir::deleteFile(): ERROR: *.trashinfo file couldn't be created!" << NL;
+        }
+        dir.setPath(baseTrash + "files");
+        if(!dir.exists()) {
+            if(!dir.mkdir(baseTrash + "files")) {
+                LOG << "PQHandlingFileDir::deleteFile(): ERROR: mkdir(files) failed!";
                 return false;
             }
+        }
+        dir.setPath(baseTrash + "info");
+        if(!dir.exists()) {
+            if(!dir.mkdir(baseTrash + "info")) {
+                LOG << "PQHandlingFileDir::deleteFile(): ERROR: mkdir(info) failed!";
+                return false;
+            }
+        }
+    } else {
+        // Set the base path ...
+        for(QStorageInfo &storage : QStorageInfo::mountedVolumes()) {
+            if(!storage.isReadOnly() && storage.isValid() && filename.startsWith(storage.rootPath()) && baseTrash.length() < storage.rootPath().length()) {
+                baseTrash = storage.rootPath();
+            }
+        }
+        baseTrash += "/" + QString("/.Trash-%1/").arg(getuid());
+        // ... and make sure all the dirs exist
+        QDir dir;
+        dir.setPath(baseTrash);
+        if(!dir.exists()) {
+            if(!dir.mkdir(baseTrash)) {
+                LOG << "PQHandlingFileDir::deleteFile(): ERROR: mkdir(baseTrash) failed!";
+                return false;
+            }
+        }
+        dir.setPath(baseTrash + "files");
+        if(!dir.exists()) {
+            if(!dir.mkdir(baseTrash + "files")) {
+                LOG << "PQHandlingFileDir::deleteFile(): ERROR: mkdir(files) failed!";
+                return false;
+            }
+        }
+        dir.setPath(baseTrash + "info");
+        if(!dir.exists()) {
+            if(!dir.mkdir(baseTrash + "info")) {
+                LOG << "PQHandlingFileDir::deleteFile(): ERROR: mkdir(info) failed!";
+                return false;
+            }
+        }
 
-        } else {
-            LOG << CURDATE << "PQHandlingFileDir::deleteFile(): ERROR: File couldn't be deleted (moving file failed)" << NL;
+    }
+
+    // that's the new trash file
+    QString trashFile = baseTrash + "files/" + QUrl::toPercentEncoding(QFileInfo(filename).fileName(),""," ");
+    QString backupTrashFile = trashFile;
+
+    // If there exists already a file with that name, we simply append the next higher number (sarting at 1)
+    QFileInfo ensure(trashFile);
+    int j = 1;
+    while(ensure.exists()) {
+        trashFile = backupTrashFile + QString(" (%1)").arg(j++);
+        ensure.setFile(trashFile);
+    }
+
+    // Write the .trashinfo file
+    QFile iF(baseTrash + "info/" + QFileInfo(trashFile).fileName() + ".trashinfo");
+    if(iF.open(QIODevice::WriteOnly)) {
+        QTextStream out(&iF);
+        out << trashinfo;
+        iF.close();
+    } else {
+        LOG << CURDATE << "PQHandlingFileDir::deleteFile(): ERROR: *.trashinfo file couldn't be created!" << NL;
+        return false;
+    }
+
+    if(info.isDir()) {
+
+        QDir dir(filename);
+        if(!dir.rename(filename, trashFile)) {
+            LOG << CURDATE << "PQHandlingFileDir::deleteFile(): ERROR: Unable to move directory to trash, path = " << trashFile.toStdString() << NL;
+            return false;
+        }
+
+        // find directory size
+        qint64 size = 0;
+        QDirIterator it(trashFile, QDirIterator::Subdirectories);
+        while(it.hasNext()) {
+            QString cur = it.next();
+            QFileInfo curinfo(cur);
+            if(curinfo.isFile()) {
+                size += curinfo.size();
+            }
+        }
+
+        // update directorysizes files
+        QFile s(baseTrash + "/directorysizes");
+        s.open(QIODevice::WriteOnly|QIODevice::Append);
+        QTextStream out(&s);
+
+        QFileInfo trashFileInfo(iF);
+        QString line = QString("%1 %2 %3\n").arg(size).arg(trashFileInfo.lastModified().toMSecsSinceEpoch()).arg(QString(QUrl::toPercentEncoding(QFileInfo(trashFile).fileName(),""," ")));
+        out << line;
+        s.close();
+
+    } else if(info.isFile()) {
+
+        QFile file(filename);
+        if(!file.rename(trashFile)) {
+            LOG << CURDATE << "PQHandlingFileDir::deleteFile(): ERROR: Unable to move file to trash, path = " << trashFile.toStdString() << NL;
             return false;
         }
 
     } else {
-        LOG << CURDATE << "PQHandlingFileDir::deleteFile(): ERROR: File '" << filename.toStdString() << "' doesn't exist...?" << NL;
+
+        LOG << CURDATE << "PQHandlingFileDir::deleteFile(): ERROR: File '" << filename.toStdString() << "' doesn't appear to be file nor folder" << NL;
         return false;
     }
 
-#endif
 #endif
 
     return true;
@@ -259,6 +412,15 @@ QString PQHandlingFileDir::getDirectory(QString path, bool lowerCase) {
 
 }
 
+QString PQHandlingFileDir::getDirectoryBaseName(QString path) {
+
+    DBG << CURDATE << "PQHandlingFileDir::getDirectoryBaseName()" << NL
+        << CURDATE << "** path = " << path.toStdString() << NL;
+
+    return QDir(path).dirName();
+
+}
+
 QString PQHandlingFileDir::getExistingDirectory(QString startDir) {
 
     DBG << CURDATE << "PQHandlingFileDir::getExistingDirectory()" << NL
@@ -529,6 +691,80 @@ QStringList PQHandlingFileDir::listArchiveContent(QString path) {
 
 }
 
+bool PQHandlingFileDir::moveFiles(QStringList filenames, QString targetDir) {
+
+    DBG << CURDATE << "PQHandlingFileDir::moveFiles()" << NL
+        << CURDATE << "** filenames = " << filenames.join(",").toStdString() << NL;
+
+    if(filenames.length() == 0) {
+        LOG << CURDATE << "PQHandlingFileDir::moveFiles(): No filenames passed on." << NL;
+        return false;
+    }
+
+    QFileInfo firstinfo = QFileInfo(filenames.at(0));
+
+    QString curdir = firstinfo.absolutePath();
+
+    if(targetDir.trimmed() == "")
+        return false;
+
+    targetDir = cleanPath(targetDir);
+
+    for(auto &f : qAsConst(filenames)) {
+
+
+        QFile file(f);
+        QFileInfo fileinfo(f);
+
+        QString newname = QString("%1/%2").arg(targetDir).arg(fileinfo.fileName());
+
+        bool skipfile = false;
+
+        // first check if target file exists
+        if(QFile::exists(newname)) {
+            QMessageBox msg;
+
+            msg.setText("Target file exists.");
+            msg.setInformativeText(QString("The target file %1 already exists. Do you want to overwrite this file? If not, then this file will be skipped.").arg(fileinfo.fileName()));
+            msg.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
+            msg.setDefaultButton(QMessageBox::Yes);
+            msg.setWindowModality(Qt::ApplicationModal);
+
+            int ret = msg.exec();
+
+            if(ret == QMessageBox::No)
+                skipfile = true;
+            else
+                QFile::remove(newname);
+        }
+
+        if(skipfile)
+            continue;
+
+        if(!file.rename(newname)) {
+            LOG << CURDATE << "PQHandlingFileDir::moveFiles(): ERROR: The file/folder could not be moved to its new location." << NL;
+            LOG << CURDATE << "PQHandlingFileDir::moveFiles(): filename: '" << fileinfo.fileName().toStdString() << "'" << NL;
+            continue;
+        } else {
+#ifdef Q_OS_WIN
+            int count = 0;
+            QFile oldfile(f);
+            while(oldfile.exists() && count < 20) {
+                QFile ff(f);
+                ff.remove();
+                std::this_thread::sleep_for(std::chrono::milliseconds(250));
+                ++count;
+            }
+#endif
+        }
+
+    }
+
+    return true;
+
+
+}
+
 QString PQHandlingFileDir::moveFile(QString filename) {
 
     DBG << CURDATE << "PQHandlingFileDir::moveFile()" << NL
