@@ -46,21 +46,6 @@ PQHandlingShareImgur::PQHandlingShareImgur(QObject *parent) : QObject(parent) {
     QDir dir;
     dir.mkpath(info.absolutePath());
 
-    // The cryptkey is based on the hostname of the machine. This way this value is preserved much more reliably.
-    int key = 0;
-    QString hostname = QSysInfo::machineHostName();
-    if(hostname.length() < 4)
-        key = 63871234;
-    else {
-        hostname = hostname.remove(5, hostname.length()+1);
-        int p = 1;
-        for(const auto &character : qAsConst(hostname)) {
-            key += character.unicode()*p;
-            p *= 10;
-        }
-    }
-    crypt = SimpleCrypt(key);
-
 }
 
 PQHandlingShareImgur::~PQHandlingShareImgur() {
@@ -388,17 +373,13 @@ int PQHandlingShareImgur::upload(QString filename) {
     }
 
     // Initiate file and open for reading
-    QFile file(filename);
-    if(!file.open(QIODevice::ReadOnly)) {
+    QFile *file = new QFile(filename);
+    if(!file->open(QIODevice::ReadOnly)) {
         if(debug)
             LOG << CURDATE << QString("ERROR! Can't open file '%1' for reading to upload to imgur.com").arg(filename).toStdString() << NL;
         return IMGUR_FILE_OPEN_ERROR;
     }
 
-    // Read binary data of file to bytearray
-    QByteArray byteArray = file.readAll();
-    file.close();
-
     // Setup network request, use XML format
     QNetworkRequest req(QUrl("https://api.imgur.com/3/image.xml"));
     // the following is not necessary (it's the default), but avoids an error message on standard output
@@ -407,7 +388,7 @@ int PQHandlingShareImgur::upload(QString filename) {
     req.setRawHeader("Authorization", QByteArray("Bearer ") + access_token.toLatin1());
 
     // Send upload request and connect to feedback signals
-    QNetworkReply *reply = networkManager->post(req, byteArray);
+    QNetworkReply *reply = networkManager->post(req, file);
     connect(reply, &QNetworkReply::finished, this, &PQHandlingShareImgur::uploadFinished);
     connect(reply, &QNetworkReply::uploadProgress, this, &PQHandlingShareImgur::uploadProgress);
     // The following has to use the old syntax, as there is also a accessor member (not a signal) to access the error with the same name
@@ -444,23 +425,20 @@ int PQHandlingShareImgur::anonymousUpload(QString filename) {
     }
 
     // Initiate file and open for reading
-    QFile file(filename);
-    if(!file.open(QIODevice::ReadOnly)) {
+    QFile *file = new QFile(filename);
+    if(!file->open(QIODevice::ReadOnly)) {
         if(debug)
             LOG << CURDATE << QString("ERROR! Can't open file '%1' for reading to upload to imgur.com").arg(filename).toStdString() << NL;
         return IMGUR_FILE_OPEN_ERROR;
     }
 
-    // Read binary data of file to bytearray
-    QByteArray byteArray = file.readAll();
-
     // Setup network request (XML format)
     QNetworkRequest request(QUrl("https://api.imgur.com/3/image.xml"));
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
     request.setRawHeader("Authorization", QString("Client-ID " + imgurClientID).toLatin1());
 
     // Send upload request and connect to feedback signals
-    QNetworkReply *reply = networkManager->post(request, byteArray);
+    QNetworkReply *reply = networkManager->post(request, file);
     connect(reply, &QNetworkReply::finished, this, &PQHandlingShareImgur::uploadFinished);
     connect(reply, &QNetworkReply::uploadProgress, this, &PQHandlingShareImgur::uploadProgress);
 #if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
