@@ -22,8 +22,14 @@
 
 #include "imageproperties.h"
 
-PQImageProperties::PQImageProperties(QObject *parent) : QObject(parent) { }
+PQImageProperties::PQImageProperties(QObject *parent) : QObject(parent) {
+    loader = nullptr;
+}
 
+PQImageProperties::~PQImageProperties() {
+    if(loader != nullptr)
+        delete loader;
+}
 
 bool PQImageProperties::isAnimated(QString path) {
 
@@ -37,9 +43,9 @@ bool PQImageProperties::isAnimated(QString path) {
 
 }
 
-bool PQImageProperties::isPopplerDocument(QString path) {
+bool PQImageProperties::isPDFDocument(QString path) {
 
-    DBG << CURDATE << "PQImageProperties::isPopplerDocument()" << NL
+    DBG << CURDATE << "PQImageProperties::isPDFDocument()" << NL
         << CURDATE << "** path = " << path.toStdString() << NL;
 
     QString suf = QFileInfo(path).suffix().toLower();
@@ -98,7 +104,28 @@ int PQImageProperties::getDocumentPages(QString path) {
     Poppler::Document* document = Poppler::Document::load(path);
     if(document && !document->isLocked())
         return document->numPages();
+#endif
+#ifdef QTPDF
+    QPdfDocument doc;
+    doc.load(path);
+    QPdfDocument::Status err = doc.status();
+    if(err == QPdfDocument::Ready)
+        return doc.pageCount();
 #endif
     return 0;
 
 }
+
+QSize PQImageProperties::getImageResolution(QString path) {
+
+    DBG << CURDATE << "PQImageProperties::getImageResolution()" << NL
+        << CURDATE << "** path = " << path.toStdString() << NL;
+
+    path = handlingFileDir.cleanPath(path);
+
+    if(loader == nullptr)
+        loader = new PQLoadImage;
+
+    return loader->loadSize(path);
+
+}
