@@ -23,15 +23,27 @@
 #ifndef PQIMAGEPROPERTIES_H
 #define PQIMAGEPROPERTIES_H
 
+#include <QtGlobal>
+
+#ifdef Q_OS_WIN
+#undef WIN32_LEAN_AND_MEAN
+#include <winsock2.h>
+#endif
+
 #include <QObject>
 #include <QImageReader>
 #include <QUrl>
 #include "../logger.h"
 #include "../settings/imageformats.h"
+#include "../imageprovider/loadimage.h"
+#include "handlingfiledir.h"
 
 #ifdef POPPLER
 #include <poppler/qt5/poppler-qt5.h>
 #endif
+#ifdef QTPDF
+#include <QtPdf>
+#endif
 
 class PQImageProperties : public QObject {
 
@@ -39,12 +51,18 @@ class PQImageProperties : public QObject {
 
 public:
     explicit PQImageProperties(QObject *parent = nullptr);
+    ~PQImageProperties();
 
     Q_INVOKABLE bool isAnimated(QString path);
-    Q_INVOKABLE bool isPopplerDocument(QString path);
+    Q_INVOKABLE bool isPDFDocument(QString path);
     Q_INVOKABLE bool isArchive(QString path);
     Q_INVOKABLE bool isVideo(QString path);
     Q_INVOKABLE int getDocumentPages(QString path);
+    Q_INVOKABLE QSize getImageResolution(QString path);
+
+private:
+    PQLoadImage *loader;
+    PQHandlingFileDir handlingFileDir;
 
 };
 
