@@ -122,21 +122,47 @@ void PQImageFormats::readFromDatabase() {
         const QString cat = query.record().value("category").toString();
         const int enabled = query.record().value("enabled").toInt();
         const int qt = query.record().value("qt").toInt();
+
+#ifndef ENABLE_WEBP
+        // if webp support is disabled we exclude it from the list of known formats
+        if(endings == "webp") {
+            continue;
+        }
+#endif
+
+#ifdef LIBVIPS
         const int libvips = query.record().value("libvips").toInt();
+#endif
 #ifdef IMAGEMAGICK
         const int imgmmagick = query.record().value("imagemagick").toInt();
 #elif defined(GRAPHICSMAGICK)
         const int imgmmagick = query.record().value("graphicsmagick").toInt();
 #endif
+#ifdef RAW
         const int libraw = query.record().value("libraw").toInt();
+#endif
+#if defined(POPPLER) || defined(QTPDF)
         const int poppler = query.record().value("poppler").toInt();
+#endif
         const int xcftools = query.record().value("xcftools").toInt();
+#ifdef DEVIL
         const int devil = query.record().value("devil").toInt();
+#endif
+#ifdef FREEIMAGE
         const int freeimage = query.record().value("freeimage").toInt();
+#endif
+#ifdef LIBARCHIVE
         const int archive = query.record().value("archive").toInt();
+#endif
+#ifdef VIDEOQT
         const int video = query.record().value("video").toInt();
+#endif
+#ifdef VIDEOMPV
         const int libmpv = query.record().value("libmpv").toInt();
+#endif
+#if defined(IMAGEMAGICK) || defined(GRAPHICSMAGICK)
         const QString im_gm_magick = query.record().value("im_gm_magick").toString();
+#endif
         const QString qt_formatname = query.record().value("qt_formatname").toString();
 
         bool supportedByAnyLibrary = false;
@@ -220,7 +246,7 @@ void PQImageFormats::readFromDatabase() {
                 mimetypes_libraw << mimetypes.split(",");
         }
 #endif
-#ifdef POPPLER
+#if defined(POPPLER) || defined(QTPDF)
         if(poppler) {
             supportedByAnyLibrary = true;
             all << "Poppler";
@@ -345,17 +371,18 @@ QVariantList PQImageFormats::getWriteableFormats() {
     QVariantList ret;
 
     QImageWriter writer;
-    QSqlQuery query("SELECT * FROM imageformats ORDER BY qt DESC", db);
+    QSqlQuery query("SELECT uniqueid,qt_formatname,endings,description,im_gm_magick FROM imageformats ORDER BY qt DESC, description ASC", db);
     while(query.next()) {
 
-        QString qt_formatname = query.record().value("qt_formatname").toString();
-        const QString endings = query.record().value("endings").toString();
-        const QString description = query.record().value("description").toString();
-        const QString magick = query.record().value("im_gm_magick").toString();
+        const QString uniqueid = query.value(0).toString();
+        QString qt_formatname = query.value(1).toString();
+        const QString endings = query.value(2).toString();
+        const QString description = query.value(3).toString();
+        const QString magick = query.value(4).toString();
 
         bool qt = false;
         bool imgm = false;
-        if(qt_formatname != "" &&writer.supportedImageFormats().contains(qt_formatname.toUtf8()))
+        if(qt_formatname != "" && writer.supportedImageFormats().contains(qt_formatname.toUtf8()))
             qt = true;
 #if defined(IMAGEMAGICK) || defined(GRAPHICSMAGICK)
         else if(magick != "") {
@@ -371,7 +398,7 @@ QVariantList PQImageFormats::getWriteableFormats() {
 
             QVariantList entry;
             entry << (qt&&imgm ? "qt/magick" : (qt ? "qt" : "magick"));
-            entry << endings << description << magick;
+            entry << uniqueid << endings << description << magick;
 
             ret << QVariant::fromValue(entry);
         }
@@ -379,33 +406,80 @@ QVariantList PQImageFormats::getWriteableFormats() {
 
     return ret;
 
+
 }
 
-QVariantMap PQImageFormats::getFormatsInfo(QString endings) {
+QString PQImageFormats::getFormatName(int uniqueid) {
+
+    DBG << CURDATE << "PQImageFormats::getFormatName()" << NL;
+    DBG << CURDATE << "** uniqueid = " << uniqueid << NL;
+
+    QSqlQuery query(db);
+    query.prepare("SELECT description FROM imageformats WHERE uniqueid=:uniqueid");
+    query.bindValue(":uniqueid", uniqueid);
+    if(!query.exec()) {
+        qWarning() << "SQL Query error:" << query.lastError().text();
+        return "[unknown]";
+    }
+
+    if(!query.next()) {
+        qWarning() << "No SQL results returned";
+        return "[unknown]";
+    }
+
+    return query.value(0).toString();
+
+}
+
+QStringList PQImageFormats::getFormatEndings(int uniqueid) {
+
+    DBG << CURDATE << "PQImageFormats::getFormatEndings()" << NL;
+    DBG << CURDATE << "** uniqueid = " << uniqueid << NL;
+
+    QSqlQuery query(db);
+    query.prepare("SELECT endings FROM imageformats WHERE uniqueid=:uniqueid");
+    query.bindValue(":uniqueid", uniqueid);
+    if(!query.exec()) {
+        qWarning() << "SQL Query error:" << query.lastError().text();
+        return QStringList();
+    }
+
+    if(!query.next()) {
+        qWarning() << "No SQL results returned";
+        return QStringList();
+    }
+
+    return query.value(0).toString().split(",");
+
+}
+
+QVariantMap PQImageFormats::getFormatsInfo(int uniqueid) {
 
     DBG << CURDATE << "PQImageFormats::getFormatsInfo()" << NL;
 
     QVariantMap ret;
 
     QSqlQuery query(db);
-    query.prepare("SELECT * FROM imageformats WHERE endings=:endings");
-    query.bindValue(":endings", endings);
+    query.prepare("SELECT * FROM imageformats WHERE uniqueid=:uniqueid");
+    query.bindValue(":uniqueid", uniqueid);
     if(!query.exec()) {
-        LOG << CURDATE << "PQImageFormats::getFormatsInfo(): SQL Query error: " << query.lastError().text().trimmed().toStdString() << NL;
+        qWarning() << "SQL Query error:" << query.lastError().text();
         return ret;
     }
 
     if(!query.next()) {
-        LOG << CURDATE << "PQImageFormats::getFormatsInfo(): No SQL results returned" << NL;
+        qWarning() << "No SQL results returned";
         return ret;
     }
 
-    ret.insert("endings", endings);
+    ret.insert("uniqueid", uniqueid);
+    ret.insert("endings", query.record().value("endings"));
     ret.insert("mimetypes", query.record().value("mimetypes"));
     ret.insert("description", query.record().value("description"));
     ret.insert("category", query.record().value("category"));
     ret.insert("enabled", query.record().value("enabled"));
     ret.insert("qt", query.record().value("qt"));
+    ret.insert("resvg", query.record().value("resvg"));
     ret.insert("libvips", query.record().value("libvips"));
     ret.insert("imagemagick", query.record().value("imagemagick"));
     ret.insert("graphicsmagick", query.record().value("graphicsmagick"));
@@ -422,6 +496,7 @@ QVariantMap PQImageFormats::getFormatsInfo(QString endings) {
 
     return ret;
 
+
 }
 
 bool PQImageFormats::enterNewFormat(QString endings, QString mimetypes, QString description, QString category, int enabled,
