@@ -63,6 +63,7 @@ class PQCommandLineParser : public QObject, public QCommandLineParser {
 public:
 
     explicit PQCommandLineParser(QApplication &app, QObject *parent = nullptr);
+    ~PQCommandLineParser();
     PQCommandLineResult getResult();
 
     QString exportFileName;
@@ -70,6 +71,9 @@ public:
     QString filename;
     QString shortcutSequence;
 
+private:
+    QTranslator trans;
+
 };
 
 
