@@ -24,9 +24,6 @@
 
 PQSingleInstance::PQSingleInstance(int &argc, char *argv[]) : QApplication(argc, argv) {
 
-    setApplicationName("photoqt");
-    setApplicationVersion(VERSION);
-
     // Parse the command line arguments
     PQCommandLineParser parser(*this);
     PQCommandLineResult result = parser.getResult();
@@ -174,6 +171,7 @@ PQSingleInstance::PQSingleInstance(int &argc, char *argv[]) : QApplication(argc,
         handleMessage(message);
 
     }
+
 }
 
 void PQSingleInstance::newConnection() {
@@ -259,10 +257,9 @@ bool PQSingleInstance::notify(QObject *receiver, QEvent *e) {
         QMouseEvent *ev = reinterpret_cast<QMouseEvent*>(e);
         if(qmlWindowAddresses.contains(receiver))
             Q_EMIT PQKeyPressMouseChecker::get().receivedMouseButtonPress(ev->buttons(), ev->pos());
-    } else if(e->type() == QEvent::MouseMove) {
-        QMouseEvent *ev = reinterpret_cast<QMouseEvent*>(e);
+    } else if(e->type() == QEvent::Leave) {
         if(qmlWindowAddresses.contains(receiver))
-            Q_EMIT PQKeyPressMouseChecker::get().receivedMouseMove(ev->pos());
+            Q_EMIT PQKeyPressMouseChecker::get().receivedMouseLeave();
     }
 
     return QApplication::notify(receiver, e);
