@@ -36,6 +36,7 @@ int PQStartup::check(bool onlyCreateDatabase) {
     QSqlDatabase db_shortcuts;
     QSqlDatabase db_context;
     QSqlDatabase db_imageformats;
+    QSqlDatabase db_location;
 
     // check if sqlite is available
     // this is a hard requirement now and we wont launch PhotoQt without it
@@ -44,11 +45,13 @@ int PQStartup::check(bool onlyCreateDatabase) {
         db_shortcuts = QSqlDatabase::addDatabase("QSQLITE3", "shortcuts");
         db_context = QSqlDatabase::addDatabase("QSQLITE3", "contextmenu");
         db_imageformats = QSqlDatabase::addDatabase("QSQLITE3", "imageformats");
+        db_location = QSqlDatabase::addDatabase("QSQLITE3", "location");
     } else if(QSqlDatabase::isDriverAvailable("QSQLITE")) {
         db_settings = QSqlDatabase::addDatabase("QSQLITE", "settings");
         db_shortcuts = QSqlDatabase::addDatabase("QSQLITE", "shortcuts");
         db_context = QSqlDatabase::addDatabase("QSQLITE", "contextmenu");
         db_imageformats = QSqlDatabase::addDatabase("QSQLITE", "imageformats");
+        db_location = QSqlDatabase::addDatabase("QSQLITE", "location");
     } else {
         LOG << CURDATE << "PQStartup::check(): ERROR: SQLite driver not available. Available drivers are: " << QSqlDatabase::drivers().join(",").toStdString() << NL;
         LOG << CURDATE << "PQStartup::check(): PhotoQt cannot function without SQLite available." << NL;
@@ -67,6 +70,7 @@ int PQStartup::check(bool onlyCreateDatabase) {
         db_shortcuts.setDatabaseName(ConfigFiles::SHORTCUTS_DB());
         db_context.setDatabaseName(ConfigFiles::CONTEXTMENU_DB());
         db_imageformats.setDatabaseName(ConfigFiles::IMAGEFORMATS_DB());
+        db_location.setDatabaseName(ConfigFiles::LOCATION_DB());
 
         return 2;
     }
@@ -75,6 +79,7 @@ int PQStartup::check(bool onlyCreateDatabase) {
     db_shortcuts.setDatabaseName(ConfigFiles::SHORTCUTS_DB());
     db_context.setDatabaseName(ConfigFiles::CONTEXTMENU_DB());
     db_imageformats.setDatabaseName(ConfigFiles::IMAGEFORMATS_DB());
+    db_location.setDatabaseName(ConfigFiles::LOCATION_DB());
 
     /******************************************************************************************************/
     // If we perform an action like export/import/check/... we need access to the db but no more than that
@@ -178,6 +183,15 @@ void PQStartup::setupFresh(int defaultPopout) {
         file.setPermissions(file.permissions()|QFileDevice::WriteOwner);
     }
 
+    /**************************************************************/
+    // create default location database
+    if(!QFile::copy(":/location.db", ConfigFiles::LOCATION_DB()))
+        LOG << CURDATE << "PQStartup::setupFresh(): unable to create location database" << NL;
+    else {
+        QFile file(ConfigFiles::LOCATION_DB());
+        file.setPermissions(file.permissions()|QFileDevice::WriteOwner);
+    }
+
     PQSettings::get().update("generalVersion", VERSION);
 
 #ifdef Q_OS_WIN
@@ -192,10 +206,13 @@ void PQStartup::setupFresh(int defaultPopout) {
         PQSettings::get().update("interfacePopoutScale", true);
         PQSettings::get().update("interfacePopoutOpenFile", true);
         PQSettings::get().update("interfacePopoutSlideShowSettings", true);
-        PQSettings::get().update("interfacePopoutSlideShowControls", true);
         PQSettings::get().update("interfacePopoutImgur", true);
         PQSettings::get().update("interfacePopoutWallpaper", true);
         PQSettings::get().update("interfacePopoutSettingsManager", true);
+        PQSettings::get().update("interfacePopoutFileSaveAs", true);
+        PQSettings::get().update("interfacePopoutChromecast", true);
+        PQSettings::get().update("interfacePopoutAdvancedSort", true);
+        PQSettings::get().update("interfacePopoutMapExplorer", true);
 
     } else if(defaultPopout == 2) { // all individual
 
@@ -216,6 +233,11 @@ void PQStartup::setupFresh(int defaultPopout) {
         PQSettings::get().update("interfacePopoutSettingsManager", true);
         PQSettings::get().update("interfacePopoutFileSaveAs", true);
         PQSettings::get().update("interfacePopoutUnavailable", true);
+        PQSettings::get().update("interfacePopoutChromecast", true);
+        PQSettings::get().update("interfacePopoutAdvancedSort", true);
+        PQSettings::get().update("interfacePopoutMapCurrent", true);
+        PQSettings::get().update("interfacePopoutMapExplorer", true);
+        PQSettings::get().update("interfacePopoutMapExplorerKeepOpen", true);
 
 
     }
@@ -293,8 +315,11 @@ bool PQStartup::renameSettings() {
     QSqlDatabase db = QSqlDatabase::database("settings");
 
     QMap<QString,QStringList> rename;
-    rename ["LabelsWindowButtonsSize"] = QStringList() << "WindowButtonsSize" << "interface";
-    rename ["LabelsManageWindow"] = QStringList() << "StatusInfoManageWindow" << "interface";
+    rename ["LabelsWindowButtonsSize"] = QStringList() << "WindowButtonsSize" << "interface";   // 3.1
+    rename ["LabelsManageWindow"] = QStringList() << "StatusInfoManageWindow" << "interface";   // 3.1
+    rename ["LiftUp"] = QStringList() << "HighlightAnimationLiftUp" << "thumbnails";            // 3.2
+    rename ["FilenameOnly"] = QStringList() << "IconsOnly" << "thumbnails";                     // 3.2
+    rename ["FilenameOnlyFontSize"] = QStringList() << "" << "thumbnails";                      // 3.2
     QMapIterator<QString, QStringList> i(rename);
     while(i.hasNext()) {
         i.next();
@@ -303,16 +328,34 @@ bool PQStartup::renameSettings() {
         QString newname = i.value().value(0);
         QString table = i.value().value(1);
 
-        QSqlQuery query(db);
-        query.prepare(QString("UPDATE '%1' SET name=:new WHERE name=:old").arg(table));
-        query.bindValue(":new", newname);
-        query.bindValue(":old", oldname);
-        if(!query.exec()) {
-            LOG << CURDATE << "PQValidate::renameSettings(): Error updating setting name (" << oldname.toStdString() << " -> " << newname.toStdString() << "): " << query.lastError().text().trimmed().toStdString() << NL;
+        // delete old setting
+        if(newname == "") {
+
+            QSqlQuery query(db);
+            query.prepare(QString("DELETE FROM '%1' WHERE name=:old").arg(table));
+            query.bindValue(":old", oldname);
+            if(!query.exec()) {
+                LOG << CURDATE << "PQValidate::renameSettings(): Error removing old setting name (" << oldname.toStdString() << "): " << query.lastError().text().trimmed().toStdString() << NL;
+                query.clear();
+                return false;
+            }
             query.clear();
-            return false;
+
+        // rename old setting
+        } else {
+
+            QSqlQuery query(db);
+            query.prepare(QString("UPDATE '%1' SET name=:new WHERE name=:old").arg(table));
+            query.bindValue(":new", newname);
+            query.bindValue(":old", oldname);
+            if(!query.exec()) {
+                LOG << CURDATE << "PQValidate::renameSettings(): Error updating setting name (" << oldname.toStdString() << " -> " << newname.toStdString() << "): " << query.lastError().text().trimmed().toStdString() << NL;
+                query.clear();
+                return false;
+            }
+            query.clear();
+
         }
-        query.clear();
     }
 
     return true;
@@ -323,30 +366,18 @@ bool PQStartup::renameShortcuts() {
 
     QSqlDatabase db = QSqlDatabase::database("shortcuts");
 
-    QMap<QString,QStringList> rename;
-    rename["__quickNavigation"] = QStringList() << "__navigationFloating" << "navigation";
+    // delete old entries
+    QSqlQuery query(db);
 
-    QMapIterator<QString, QStringList> i(rename);
-    while(i.hasNext()) {
-        i.next();
-
-        QString oldname = i.key();
-        QString newname = i.value().value(0);
-        QString cat = i.value().value(1);
-
-        QSqlQuery query(db);
-        query.prepare("UPDATE 'builtin' SET command=:new WHERE command=:old AND category=:cat");
-        query.bindValue(":new", newname);
-        query.bindValue(":old", oldname);
-        query.bindValue(":cat", cat);
-        if(!query.exec()) {
-            LOG << CURDATE << "PQValidate::renameShortcuts(): Error updating shortcuts command (" << oldname.toStdString() << " -> " << newname.toStdString() << "): " << query.lastError().text().trimmed().toStdString() << NL;
-            query.clear();
-            return false;
-        }
+    // required for transition to v3.3
+    if(!query.exec("DELETE FROM builtin WHERE command like '__keepMetaData'")) {
+        LOG << CURDATE << "PQValidate::renameShortcuts(): Error removing old shortcut '__keepMetaData': " << query.lastError().text().trimmed().toStdString() << NL;
         query.clear();
+        return false;
     }
 
+    query.clear();
+
     return true;
 
 }
@@ -433,7 +464,7 @@ bool PQStartup::migrateContextmenuToDb() {
 
     if(QFile::exists(QString("%1.pre-v2.5").arg(ConfigFiles::CONTEXTMENU_FILE())))
         if(!QFile::remove(ConfigFiles::CONTEXTMENU_FILE()))
-            LOG << CURDATE << "PQStartup::migrateShortcutsToDb(): Failed to remove old contextmenu file" << NL;
+            LOG << CURDATE << "PQStartup::migrateContextmenuToDb(): Failed to remove old contextmenu file" << NL;
 
     return true;
 
@@ -441,183 +472,23 @@ bool PQStartup::migrateContextmenuToDb() {
 
 bool PQStartup::migrateShortcutsToDb() {
 
-    QFile file(ConfigFiles::SHORTCUTS_FILE());
     QFile dbfile(ConfigFiles::SHORTCUTS_DB());
 
     // if the database doesn't exist, we always need to create it
     if(!dbfile.exists()) {
-        if(!QFile::copy(":/shortcuts.db", ConfigFiles::SHORTCUTS_DB()))
+        if(!QFile::copy(":/shortcuts.db", ConfigFiles::SHORTCUTS_DB())) {
             LOG << CURDATE << "PQStartup::migrateShortcutsToDb: unable to create shortcuts database" << NL;
-        else {
+            return false;
+        } else {
             QFile file(ConfigFiles::SHORTCUTS_DB());
             file.setPermissions(file.permissions()|QFileDevice::WriteOwner);
+            return true;
         }
     }
 
-    // nothing to migrate -> we're done
-    if(!file.exists())
-        return true;
-
-
-    // access database
-    QSqlDatabase db = QSqlDatabase::database("shortcuts");
-
-    // open database
-    if(!db.open()) {
-        LOG << CURDATE << "PQStartup::migrateShortcutsToDb(): Error opening database: " << db.lastError().text().trimmed().toStdString() << NL;
-        return false;
-    }
-
-    if(!file.open(QIODevice::ReadOnly)) {
-        LOG << CURDATE << "PQStartup::migrateShortcutsToDb(): Failed to open old shortcuts file" << NL;
-        return false;
-    }
-
-    QTextStream in(&file);
-    QString txt = file.readAll();
-
-    // before 2.3, we used an old format
-    // for 2.3 and 2.4, the format was already better
-    bool oldFormat = false;
-    if(txt.contains("Version=") && !txt.contains("Version=dev")) {
-        double oldVersion = txt.split("Version=").at(1).split("\n").at(0).toDouble();
-        if(oldVersion < 2.3)
-            oldFormat = true;
-    }
-
-    // old pre-2.3 format
-    if(oldFormat) {
-
-        // first we need to collect the shortcuts set for each command
-        QMap<QString, QStringList> newShortcuts;
-
-        const QStringList parts = txt.split("\n");
-        for(const QString &p : parts) {
-
-            if(!p.contains("::"))
-                continue;
-
-            const QStringList entries = p.split("::");
-            if(entries.count() > 3 || entries.at(1) == "__")
-                continue;
-
-            const QString cmd = QString("%1::%2").arg(entries.at(0), entries.at(2));
-            const QString sh = entries.at(1);
-
-            if(newShortcuts.contains(cmd))
-                newShortcuts[cmd].append(sh);
-            else
-                newShortcuts.insert(cmd, QStringList() << sh);
-
-        }
-
-        db.transaction();
-
-        // write shortcuts to database
-        QMap<QString, QStringList>::const_iterator iter = newShortcuts.constBegin();
-        while(iter != newShortcuts.constEnd()) {
-
-            const QString close = iter.key().split("::").at(0);
-            const QString cmd = iter.key().split("::").at(1);
-            const QString sh = iter.value().join(", ");
-
-            if(cmd.startsWith("__")) {
-
-                QSqlQuery query(db);
-                query.prepare("UPDATE builtin SET shortcuts=:sh WHERE command=:cmd");
-                query.bindValue(":sh", sh);
-                query.bindValue(":cmd", cmd);
-                if(!query.exec())
-                    LOG << CURDATE << "PQStartup::migrateShortcutsToDb(): SQL Error [1]: " << query.lastError().text().trimmed().toStdString() << NL;
-
-            } else {
-
-                QSqlQuery query(db);
-                query.prepare("INSERT INTO external (command,shortcuts,close) VALUES(:cmd,:sh,:cl)");
-                query.bindValue(":sh", sh);
-                query.bindValue(":cl", close);
-                query.bindValue(":cmd", cmd);
-                if(!query.exec())
-                    LOG << CURDATE << "PQStartup::migrateShortcutsToDb(): SQL Error [2]: " << query.lastError().text().trimmed().toStdString() << NL;
-
-            }
-
-            ++iter;
-
-        }
-
-        db.commit();
-
-    // format of 2.3 and 2.4
-    } else {
-
-        const QStringList parts = txt.split("\n");
-
-        db.transaction();
-
-        for(const auto &line : parts) {
-
-            if(line.startsWith("Version="))
-                continue;
-
-            QStringList p = line.split("::");
-            if(p.length() < 3)
-                continue;
-
-            const QString close = p.at(0);
-            const QString cmd = p.at(1);
-            const QString sh = p.mid(2).join(", ");
-
-            if(cmd.startsWith("__")) {
-
-                QSqlQuery query(db);
-                query.prepare("UPDATE builtin SET shortcuts=:sh WHERE command=:cmd");
-                query.bindValue(":sh", sh);
-                query.bindValue(":cmd", cmd);
-                if(!query.exec())
-                    LOG << CURDATE << "PQStartup::migrateShortcutsToDb(): SQL Error [3]: " << query.lastError().text().trimmed().toStdString() << NL;
-
-            } else {
-
-                QSqlQuery query(db);
-                query.prepare("INSERT INTO external (command,shortcuts,close) VALUES(:cmd,:sh,:cl)");
-                query.bindValue(":sh", sh);
-                query.bindValue(":cl", close);
-                query.bindValue(":cmd", cmd);
-                if(!query.exec())
-                    LOG << CURDATE << "PQStartup::migrateShortcutsToDb(): SQL Error [4]: " << query.lastError().text().trimmed().toStdString() << NL;
-
-            }
-
-        }
-
-        // add __chromecast as shortcut (no default set)
-        QSqlQuery query(db);
-        query.prepare("INSERT OR IGNORE INTO builtin (category, command, shortcuts, defaultshortcuts) VALUES(:cat, :cmd, :sh, :def)");
-        query.bindValue(":cat", "other");
-        query.bindValue(":cmd", "__chromecast");
-        query.bindValue(":sh", "");
-        query.bindValue(":def", "");
-        if(!query.exec())
-            LOG << CURDATE << "PQStartup::migrateShortcutsToDb(): SQL Error, insert new: " << query.lastError().text().trimmed().toStdString() << NL;
-
-        db.commit();
-
-    }
-
-    QString oldfile = QString("%1.pre-v2.5").arg(ConfigFiles::SHORTCUTS_FILE());
-    if(!QFile::exists(oldfile)) {
-        if(!QFile::copy(ConfigFiles::SHORTCUTS_FILE(), oldfile))
-            LOG << CURDATE << "PQStartup::migrateShortcutsToDb(): Failed to copy old shortcuts file to 'shortcuts.pre-v2.5' filename" << NL;
-        QFile file(oldfile);
-        file.setPermissions(file.permissions()|QFileDevice::WriteOwner);
-    }
-
-    if(QFile::exists(QString("%1.pre-v2.5").arg(ConfigFiles::SHORTCUTS_FILE())))
-        if(!QFile::remove(ConfigFiles::SHORTCUTS_FILE()))
-            LOG << CURDATE << "PQStartup::migrateShortcutsToDb(): Failed to remove old shortcuts file" << NL;
-
-    return true;
+    // we already do the potential migration there, do again here
+    PQValidate validate;
+    return validate.validateShortcutsDatabase();
 
 }
 
