@@ -35,7 +35,13 @@ bool PQValidate::validate() {
 
     bool success = true;
 
-    bool ret = validateSettingsDatabase();
+    bool ret = validateDirectories();
+    if(!ret) {
+        LOG << " >> Failed: directories" << NL << NL;
+        success = false;
+    }
+
+    ret = validateSettingsDatabase();
     if(!ret) {
         LOG << " >> Failed: settings db" << NL << NL;
         success = false;
@@ -65,13 +71,43 @@ bool PQValidate::validate() {
         success = false;
     }
 
+    ret = validateLocationDatabase();
+    if(!ret) {
+        LOG << " >> Failed: location db" << NL << NL;
+        success = false;
+    }
+
     LOG << " >> Done!" << NL << NL;
     return success;
 
 }
 
+bool PQValidate::validateDirectories() {
+
+    // make sure necessary folder exist
+    QDir dir;
+    dir.mkpath(ConfigFiles::CONFIG_DIR());
+    dir.mkpath(ConfigFiles::GENERIC_DATA_DIR());
+    dir.mkpath(ConfigFiles::GENERIC_CACHE_DIR());
+    dir.mkpath(QString("%1/thumbnails/large/").arg(ConfigFiles::GENERIC_CACHE_DIR()));
+
+    return true;
+
+}
+
 bool PQValidate::validateContextMenuDatabase() {
 
+    // the db does not exist -> create it and finish
+    if(!QFile::exists(ConfigFiles::CONTEXTMENU_DB())) {
+        if(!QFile::copy(":/contextmenu.db", ConfigFiles::CONTEXTMENU_DB()))
+            LOG << CURDATE << "PQValidate::validateContextMenuDatabase(): unable to (re-)create default contextmenu database" << NL;
+        else {
+            QFile file(ConfigFiles::CONTEXTMENU_DB());
+            file.setPermissions(file.permissions()|QFileDevice::WriteOwner);
+        }
+        return true;
+    }
+
     QSqlDatabase dbinstalled = QSqlDatabase::database("contextmenu");
 
     if(!dbinstalled.open())
@@ -185,6 +221,17 @@ bool PQValidate::validateContextMenuDatabase() {
 
 bool PQValidate::validateImageFormatsDatabase() {
 
+    // the db does not exist -> create it and finish
+    if(!QFile::exists(ConfigFiles::IMAGEFORMATS_DB())) {
+        if(!QFile::copy(":/imageformats.db", ConfigFiles::IMAGEFORMATS_DB()))
+            LOG << CURDATE << "PQValidate::validateImageFormatsDatabase(): unable to (re-)create default imageformats database" << NL;
+        else {
+            QFile file(ConfigFiles::IMAGEFORMATS_DB());
+            file.setPermissions(file.permissions()|QFileDevice::WriteOwner);
+        }
+        return true;
+    }
+
     // here we check all the image formats
     // we do so automatically by loading the default imageformats database and check that all items there are present in the actual one
 
@@ -261,7 +308,7 @@ bool PQValidate::validateImageFormatsDatabase() {
     query.clear();
 
     // get reference data
-    query.prepare("SELECT endings,mimetypes,description,category,enabled,qt,libvips,imagemagick,graphicsmagick,libraw,poppler,xcftools,devil,freeimage,archive,video,libmpv,im_gm_magick,qt_formatname FROM 'imageformats'");
+    query.prepare("SELECT endings,mimetypes,description,category,enabled,qt,libvips,imagemagick,graphicsmagick,libraw,poppler,xcftools,devil,freeimage,archive,video,libmpv,im_gm_magick,qt_formatname,uniqueid FROM 'imageformats'");
     if(!query.exec()) {
         LOG << CURDATE << "PQValidate::validateImageFormatsDatabase(): Error getting default data: " << query.lastError().text().trimmed().toStdString() << NL;
         query.clear();
@@ -296,6 +343,8 @@ bool PQValidate::validateImageFormatsDatabase() {
         const QString im_gm_magick = query.value(17).toString();
         const QString qt_formatname = query.value(18).toString();
 
+        const int uniqueid = query.value(19).toInt();
+
         // check whether an entry with that name exists in the in-production database
         QSqlQuery check(dbinstalled);
         check.prepare("SELECT count(endings) FROM imageformats WHERE endings=:endings");
@@ -329,7 +378,7 @@ bool PQValidate::validateImageFormatsDatabase() {
         if(count == 0) {
 
             QSqlQuery insquery(dbinstalled);
-            insquery.prepare("INSERT INTO imageformats (endings,mimetypes,description,category,enabled,qt,libvips,imagemagick,graphicsmagick,libraw,poppler,xcftools,devil,freeimage,archive,video,libmpv,im_gm_magick,qt_formatname) VALUES(:endings,:mimetypes,:description,:category,:enabled,:qt,:libvips,:imagemagick,:graphicsmagick,:libraw,:poppler,:xcftools,:devil,:freeimage,:archive,:video,:libmpv,:im_gm_magick,:qt_formatname)");
+            insquery.prepare("INSERT INTO imageformats (endings,mimetypes,description,category,enabled,qt,libvips,imagemagick,graphicsmagick,libraw,poppler,xcftools,devil,freeimage,archive,video,libmpv,im_gm_magick,qt_formatname,uniqueid) VALUES(:endings,:mimetypes,:description,:category,:enabled,:qt,:libvips,:imagemagick,:graphicsmagick,:libraw,:poppler,:xcftools,:devil,:freeimage,:archive,:video,:libmpv,:im_gm_magick,:qt_formatname,:uniqueid)");
             insquery.bindValue(":endings", endings);
             insquery.bindValue(":mimetypes", mimetypes);
             insquery.bindValue(":description", description);
@@ -352,6 +401,7 @@ bool PQValidate::validateImageFormatsDatabase() {
             insquery.bindValue(":libmpv", libmpv);
             insquery.bindValue(":im_gm_magick", im_gm_magick);
             insquery.bindValue(":qt_formatname", qt_formatname);
+            insquery.bindValue(":uniqueid", uniqueid);
 
             if(!insquery.exec()) {
                 LOG << CURDATE << "PQValidate::validateImageFormatsDatabase(): ERROR inserting missing image format " << endings.toStdString() << ": " << insquery.lastError().text().trimmed().toStdString() << NL;
@@ -363,9 +413,9 @@ bool PQValidate::validateImageFormatsDatabase() {
 
             QSqlQuery check(dbinstalled);
             if(updateByEnding)
-                check.prepare("UPDATE imageformats SET  mimetypes=:mimetypes, description=:description, category=:category, qt=:qt, libvips=:libvips, imagemagick=:imagemagick, graphicsmagick=:graphicsmagick, libraw=:libraw, poppler=:poppler, xcftools=:xcftools, devil=:devil, freeimage=:freeimage, archive=:archive, video=:video, libmpv=:libmpv, im_gm_magick=:im_gm_magick, qt_formatname=:qt_formatname WHERE endings=:endings");
+                check.prepare("UPDATE imageformats SET  uniqueid=:uniqueid, mimetypes=:mimetypes, description=:description, category=:category, qt=:qt, libvips=:libvips, imagemagick=:imagemagick, graphicsmagick=:graphicsmagick, libraw=:libraw, poppler=:poppler, xcftools=:xcftools, devil=:devil, freeimage=:freeimage, archive=:archive, video=:video, libmpv=:libmpv, im_gm_magick=:im_gm_magick, qt_formatname=:qt_formatname WHERE endings=:endings");
             else
-                check.prepare("UPDATE imageformats SET  endings=:endings, mimetypes=:mimetypes, category=:category, qt=:qt, libvips=:libvips, imagemagick=:imagemagick, graphicsmagick=:graphicsmagick, libraw=:libraw, poppler=:poppler, xcftools=:xcftools, devil=:devil, freeimage=:freeimage, archive=:archive, video=:video, libmpv=:libmpv, im_gm_magick=:im_gm_magick, qt_formatname=:qt_formatname WHERE description=:description");
+                check.prepare("UPDATE imageformats SET  uniqueid=:uniqueid, endings=:endings, mimetypes=:mimetypes, category=:category, qt=:qt, libvips=:libvips, imagemagick=:imagemagick, graphicsmagick=:graphicsmagick, libraw=:libraw, poppler=:poppler, xcftools=:xcftools, devil=:devil, freeimage=:freeimage, archive=:archive, video=:video, libmpv=:libmpv, im_gm_magick=:im_gm_magick, qt_formatname=:qt_formatname WHERE description=:description");
 
             check.bindValue(":endings", endings);
             check.bindValue(":mimetypes", mimetypes);
@@ -385,6 +435,7 @@ bool PQValidate::validateImageFormatsDatabase() {
             check.bindValue(":libmpv", libmpv);
             check.bindValue(":im_gm_magick", im_gm_magick);
             check.bindValue(":qt_formatname", qt_formatname);
+            check.bindValue(":uniqueid", uniqueid);
 
             if(!check.exec()) {
                 LOG << CURDATE << "PQValidate::validateImageFormatsDatabase(): Error updating defaultvalue and datatype: " << endings.toStdString() << ": " << check.lastError().text().trimmed().toStdString() << NL;
@@ -456,6 +507,17 @@ bool PQValidate::validateImageFormatsDatabase() {
 
 bool PQValidate::validateSettingsDatabase() {
 
+    // the db does not exist -> create it and finish
+    if(!QFile::exists(ConfigFiles::SETTINGS_DB())) {
+        if(!QFile::copy(":/settings.db", ConfigFiles::SETTINGS_DB()))
+            LOG << CURDATE << "PQValidate::validateSettingsDatabase(): unable to (re-)create default settings database" << NL;
+        else {
+            QFile file(ConfigFiles::SETTINGS_DB());
+            file.setPermissions(file.permissions()|QFileDevice::WriteOwner);
+        }
+        return true;
+    }
+
     // first we check all the settings
     // we do so automatically by loading the default settings database and check that all items there are present in the actual one
 
@@ -493,12 +555,45 @@ bool PQValidate::validateSettingsDatabase() {
         return false;
     }
 
+    QStringList whichTablesToAdd;
+
     // iterate over all tables
-    while(queryTables.next())
-        tables << queryTables.value(0).toString();
+    while(queryTables.next()) {
+        const QString tab = queryTables.value(0).toString();
+        tables << tab;
+
+        // make sure all tables exist in installed db
+
+        QSqlQuery queryTabIns(dbinstalled);
+        if(!queryTabIns.exec(QString("SELECT COUNT(name) as cnt FROM sqlite_master WHERE type='table' AND name='%1'").arg(tab))) {
+            LOG << CURDATE << "PQValidate::validateSettingsDatabase(): Error checking table '" << tab.toStdString() << "' existence: " << queryTabIns.lastError().text().toStdString() << NL;
+            continue;
+        }
+
+        queryTabIns.next();
+
+        int cnt = queryTabIns.value(0).toInt();
+        if(cnt == 0)
+            whichTablesToAdd << tab;
+
+        queryTabIns.clear();
+    }
 
     queryTables.clear();
 
+    // add missing tables
+    if(whichTablesToAdd.length() > 0) {
+
+        for(const QString &tab : qAsConst(whichTablesToAdd)) {
+
+            QSqlQuery queryTabIns(dbinstalled);
+            if(!queryTabIns.exec(QString("CREATE TABLE `%1` (`name` TEXT UNIQUE, `value` TEXT, `defaultvalue` TEXT, `datatype` TEXT)").arg(tab)))
+                LOG << CURDATE << "PQValidate::validateSettingsDatabase(): ERROR adding missing table '" << tab.toStdString() << "': " << queryTabIns.lastError().text().toStdString() << NL;
+            queryTabIns.clear();
+        }
+
+    }
+
     QSqlQuery query(dbdefault);
 
     for(const auto &table : qAsConst(tables)) {
@@ -629,6 +724,20 @@ bool PQValidate::validateSettingsDatabase() {
 
 bool PQValidate::validateShortcutsDatabase() {
 
+    // This is also called in PQStartup::migrateShortcutsToDb()
+    // and PQHandlingExternal::importConfigFrom()
+
+    // the db does not exist -> create it and finish
+    if(!QFile::exists(ConfigFiles::SHORTCUTS_DB())) {
+        if(!QFile::copy(":/shortcuts.db", ConfigFiles::SHORTCUTS_DB()))
+            LOG << CURDATE << "PQValidate::validateShortcutsDatabase(): unable to (re-)create default shortcuts database" << NL;
+        else {
+            QFile file(ConfigFiles::SHORTCUTS_DB());
+            file.setPermissions(file.permissions()|QFileDevice::WriteOwner);
+        }
+        return true;
+    }
+
     QSqlDatabase dbinstalled = QSqlDatabase::database("shortcuts");
 
     QSqlDatabase dbdefault;
@@ -642,203 +751,148 @@ bool PQValidate::validateShortcutsDatabase() {
         return false;
     }
 
-    /****************************************************/
-    // First update external table
-
-    QSqlQuery queryCol(dbinstalled);
-    if(!queryCol.exec("SELECT count() FROM PRAGMA_TABLE_INFO('external')")) {
-        LOG << CURDATE << "PQValidate::validateShortcutsDatabase(): Error validating 'external' columns: " << queryCol.lastError().text().trimmed().toStdString() << NL;
-        queryCol.clear();
-        return false;
-    }
-
-    queryCol.next();
-    int c = queryCol.value(0).toInt();
-    queryCol.clear();
-
-    // If database needs to be migrated
-    if(c == 3) {
-
-        // backup old database
-        QFile f(ConfigFiles::SHORTCUTS_DB());
-        if(QFileInfo::exists(ConfigFiles::SHORTCUTS_DB() + ".bak"))
-            QFile::remove(ConfigFiles::SHORTCUTS_DB()+".bak");
-        if(!f.copy(ConfigFiles::SHORTCUTS_DB() + ".bak"))
-            LOG << CURDATE << "PQValidate::validateShortcutsDatabase(): Unable to backup old database, copying failed" << NL;
-
-        // add new column
-        if(!queryCol.exec("ALTER TABLE external ADD COLUMN arguments TEXT")) {
-            LOG << CURDATE << "PQValidate::validateShortcutsDatabase(): Error adding 'arguments' columns to 'external' table: " << queryCol.lastError().text().trimmed().toStdString() << NL;
-            queryCol.clear();
-            return false;
-        }
-
-        // Loop over existing data and update with new format
-        queryCol.clear();
-
-        if(!queryCol.exec("SELECT command,shortcuts,close FROM external")) {
-            LOG << CURDATE << "PQValidate::validateShortcutsDatabase(): Unable to migrate external shortcuts: " << queryCol.lastError().text().trimmed().toStdString() << NL;
-            queryCol.clear();
-            return false;
-        }
-
-        // save migrated data in list
-        QList<QStringList> lst;
-        while(queryCol.next()) {
-
-            QStringList oldexe = queryCol.value(0).toString().split(" ");
-            QString exec = oldexe.takeFirst();
-            QString args = oldexe.join(" ");
-
-            lst.append({exec, args, queryCol.value(1).toString(), queryCol.value(2).toString()});
-
-        }
-        queryCol.clear();
-
-        // if external shortcuts were set
-        if(lst.length() > 0) {
-
-            // delete old data
-            if(!queryCol.exec("DELETE FROM external")) {
-                LOG << CURDATE << "PQValidate::validateShortcutsDatabase(): Unable to remove old external shortcuts to fill in migrated data: " << queryCol.lastError().text().trimmed().toStdString() << NL;
-                queryCol.clear();
-                return false;
-            }
-            queryCol.clear();
-
-            // insert migrated data
-            for(const auto &l : qAsConst(lst)) {
-
-                QSqlQuery queryNew(dbinstalled);
-                queryNew.prepare("INSERT INTO external (command, arguments, shortcuts, close) VALUES (:cmd, :arg, :sh, :cl)");
-                queryNew.bindValue(":cmd", l[0]);
-                queryNew.bindValue(":arg", l[1]);
-                queryNew.bindValue(":sh", l[2]);
-                queryNew.bindValue(":cl", l[3]);
-                if(!queryNew.exec()) {
-                    LOG << CURDATE << "PQValidate::validateShortcutsDatabase(): Unable to insert migrated data, old data might be lost: " << queryNew.lastError().text().trimmed().toStdString() << NL;
-                    queryNew.clear();
-                    return false;
-                }
-            }
-
-        }
-
-    }
-
-    /****************************************************/
-    // Validate with default data
-
-    // open database
-    QFile::remove(ConfigFiles::CACHE_DIR()+"/photoqt_tmp.db");
-    QFile::copy(":/shortcuts.db", ConfigFiles::CACHE_DIR()+"/photoqt_tmp.db");
-    QFile::setPermissions(ConfigFiles::CACHE_DIR()+"/photoqt_tmp.db",
-                          QFileDevice::WriteOwner|QFileDevice::ReadOwner |
-                          QFileDevice::ReadGroup);
-    dbdefault.setDatabaseName(ConfigFiles::CACHE_DIR()+"/photoqt_tmp.db");
-    if(!dbdefault.open())
-        LOG << CURDATE << "PQValidate::validateShortcutsDatabase(): Error opening default database: " << dbdefault.lastError().text().trimmed().toStdString() << NL;
-
-    QSqlQuery query(dbdefault);
-
-    // get reference data
-    query.prepare("SELECT category,command,shortcuts,defaultshortcuts FROM 'builtin'");
-    if(!query.exec()) {
-        LOG << CURDATE << "PQValidate::validateShortcutsDatabase(): Error getting default data: " << query.lastError().text().trimmed().toStdString() << NL;
+    // check for status of database
+    QSqlQuery query(dbinstalled);
+    if(!query.exec("SELECT count() FROM PRAGMA_TABLE_INFO('shortcuts')")) {
+        LOG << CURDATE << "PQValidate::validateShortcutsDatabase(): Error checking for 'shortcuts' columns: " << query.lastError().text().trimmed().toStdString() << NL;
         query.clear();
-        QFile::remove(ConfigFiles::CACHE_DIR()+"/photoqt_tmp.db");
         return false;
     }
 
-    // loop over reference data
-    while(query.next()) {
-
-        const QString category = query.value(0).toString();
-        const QString command = query.value(1).toString();
-        QString shortcuts = query.value(2).toString();
-        const QString defaultshortcuts = query.value(3).toString();
-
-        // check whether an entry with that name exists in the in-production database
-        QSqlQuery check(dbinstalled);
-        check.prepare("SELECT count(category) FROM builtin WHERE command=:command");
-        check.bindValue(":command", command);
-        if(!check.exec()) {
-            LOG << CURDATE << "PQValidate::validateShortcutsDatabase(): Error checking entry: " << command.toStdString() << ": " << check.lastError().text().trimmed().toStdString() << NL;
-            continue;
-        }
-        check.next();
-        int count = check.value(0).toInt();
-
-        check.clear();
-
-        // if there are multiples, we first get and store the possible desired value and then remove all of them
-        if(count > 1) {
-
-            QSqlQuery rem(dbinstalled);
-            rem.prepare("SELECT shortcuts FROM builtin WHERE command=:cmd AND shortcuts!=''");
-            rem.bindValue(":cmd", command);
-            if(!rem.exec()) {
-                LOG << CURDATE << "PQValidate::validateShortcutsDatabase(): ERROR getting value of multiples " << command.toStdString() << ": " << rem.lastError().text().trimmed().toStdString() << NL;
-                continue;
-            }
-            if(rem.next())
-                shortcuts = rem.value(0).toString();
-            else
-                shortcuts = "";
-
-            rem.clear();
-
-            rem.prepare("DELETE FROM builtin WHERE command=:cmd");
-            rem.bindValue(":cmd", command);
-            if(!rem.exec()) {
-                LOG << CURDATE << "PQValidate::validateShortcutsDatabase(): ERROR removing multiples " << command.toStdString() << ": " << rem.lastError().text().trimmed().toStdString() << NL;
-                continue;
-            }
-            rem.clear();
-
-            count = 0;
-        }
-
-        // if entry does not exist, add it
-        if(count == 0) {
-
-            QSqlQuery insquery(dbinstalled);
-            insquery.prepare("INSERT INTO builtin (category,command,shortcuts,defaultshortcuts) VALUES(:cat,:cmd,:sh,:def)");
-            insquery.bindValue(":cat", category);
-            insquery.bindValue(":cmd", command);
-            insquery.bindValue(":sh", shortcuts);
-            insquery.bindValue(":def", defaultshortcuts);
-
-            if(!insquery.exec()) {
-                LOG << CURDATE << "PQValidate::validateShortcutsDatabase(): ERROR inserting missing entry " << command.toStdString() << ": " << insquery.lastError().text().trimmed().toStdString() << NL;
-                continue;
-            }
-
-        // if entry does exist, make sure category and defaultshortcuts is valid
-        } else {
-
-            QSqlQuery check(dbinstalled);
-            check.prepare("UPDATE builtin SET category=:cat,defaultshortcuts=:def WHERE command=:cmd");
-            check.bindValue(":cat", category);
-            check.bindValue(":def", defaultshortcuts);
-            check.bindValue(":cmd", command);
-            if(!check.exec()) {
-                LOG << CURDATE << "PQValidate::validateShortcutsDatabase(): Error updating defaultvalue and datatype: " << command.toStdString() << ": " << check.lastError().text().trimmed().toStdString() << NL;
-                continue;
-            }
-            check.clear();
-
-        }
-
-    }
-
+    query.next();
+    int c = query.value(0).toInt();
     query.clear();
 
-    dbdefault.close();
+    // c==0 means that there is no shortcuts table yet
+    // and this implies the database still needs to be converted
+    if(c == 0) {
 
-    QFile file(ConfigFiles::CACHE_DIR()+"/photoqt_tmp.db");
-    if(!file.remove())
-        LOG << CURDATE << "PQValidate::validateShortcutsDatabase(): ERROR: Unable to remove ref db: " << file.errorString().toStdString() << NL;
+        // converting the old database to the new format is relatively straight forward
+        // as we can keep the old two tables around since the new table is called something different
+
+        // create new table
+        QSqlQuery query(dbinstalled);
+        if(!query.exec("CREATE TABLE 'shortcuts' (`combo` TEXT UNIQUE,`commands` TEXT,`cycle` INTEGER,`cycletimeout` INTEGER,`simultaneous` INTEGER)")) {
+            LOG << CURDATE << "PQValidate::validateShortcutsDatabase(): ERROR: Unable to create new shortcuts table: " << query.lastError().text().trimmed().toStdString() << NL;
+            query.clear();
+            return false;
+        }
+
+        // then we load the old data into a map
+        QMap<QString, QStringList> data;
+
+        // first the builtin data
+        if(!query.exec("SELECT command,shortcuts FROM builtin")) {
+            LOG << CURDATE << "PQValidate::validateShortcutsDatabase(): ERROR: Unable to read old builtin data: " << query.lastError().text().trimmed().toStdString() << NL;
+            query.clear();
+            return false;
+        }
+
+        while(query.next()) {
+
+            const QString cmd = query.value(0).toString();
+            const QStringList sh = query.value(1).toString().split(", ");
+
+            for(const QString &s : sh) {
+
+                if(s == "")
+                    continue;
+
+                // The default database does not have a space after the comma in this one case
+                if(s == "Escape,O") {
+                    if(data.keys().contains("Escape"))
+                        data["Escape"].push_back(cmd);
+                    else
+                        data["Escape"] = QStringList() << cmd;
+                    if(data.keys().contains("O"))
+                        data["O"].push_back(cmd);
+                    else
+                        data["O"] = QStringList() << cmd;
+                } else {
+
+                    if(data.keys().contains(s))
+                        data[s.trimmed()].push_back(cmd);
+                    else
+                        data[s.trimmed()] = QStringList() << cmd;
+
+                }
+
+            }
+
+        }
+
+        query.clear();
+
+        // then the external data
+        if(!query.exec("SELECT command,arguments,shortcuts,close FROM external")) {
+            LOG << CURDATE << "PQValidate::validateShortcutsDatabase(): ERROR: Unable to read old external data: " << query.lastError().text().trimmed().toStdString() << NL;
+            query.clear();
+            return false;
+        }
+
+        while(query.next()) {
+
+            QString cmd = query.value(0).toString();
+            QString args = query.value(1).toString();
+            const QString sh = query.value(2).toString();
+            const int close = query.value(3).toInt();
+
+            if(sh == "")
+                continue;
+
+            if(args.trimmed() == "" && cmd.contains(":://:://::")) {
+                args = cmd.split(":://:://::")[1];
+                cmd = cmd.split(":://:://::")[0];
+            }
+
+            QString val = QString("%1:/:/:%2:/:/:%3").arg(cmd).arg(args).arg(close);
+
+            if(data.keys().contains(sh))
+                data[sh.trimmed()].push_back(val);
+            else
+                data[sh.trimmed()] = QStringList() << val;
+
+        }
+
+        dbinstalled.transaction();
+
+        QMapIterator<QString, QStringList> iter(data);
+        while (iter.hasNext()) {
+            iter.next();
+
+            QSqlQuery query(dbinstalled);
+
+            const QString sh = iter.key();
+            const QStringList cmd = iter.value();
+            if(cmd.length() == 0)
+                continue;
+            else if(cmd.length() == 1)
+                query.prepare("INSERT INTO 'shortcuts' (`combo`,`commands`,`cycle`,`cycletimeout`,`simultaneous`) VALUES (:combo, :cmd, 1, 0, 0)");
+            else
+                query.prepare("INSERT INTO 'shortcuts' (`combo`,`commands`,`cycle`,`cycletimeout`,`simultaneous`) VALUES (:combo, :cmd, 0, 0, 1)");
+
+            query.bindValue(":combo", sh);
+            query.bindValue(":cmd", cmd);
+
+            if(!query.exec()) {
+                LOG << CURDATE << "PQValidate::validateShortcutsDatabase(): ERROR: Unable to write new data: " << query.lastError().text().trimmed().toStdString() << NL;
+                query.clear();
+                return false;
+            }
+
+            query.clear();
+
+        }
+
+        dbinstalled.commit();
+        if(dbinstalled.lastError().text().trimmed().length()) {
+            LOG << "PQValidate::validateShortcutsDatabase(): ERROR committing database: "
+                << dbinstalled.lastError().text().trimmed().toStdString()
+                << NL;
+            return false;
+        }
+
+    }
 
     return true;
 
@@ -918,8 +972,6 @@ bool PQValidate::validateSettingsValues() {
     for(int i = 0; i < toUpdate.size(); ++i) {
         QList<QVariant> lst = toUpdate.at(i);
 
-        qDebug() << "updating:" << lst;
-
         QSqlQuery query(dbinstalled);
 
         query.prepare(QString("UPDATE %1 SET value=:val WHERE name=:name").arg(lst.at(0).toString()));
@@ -947,3 +999,19 @@ bool PQValidate::validateSettingsValues() {
     return true;
 
 }
+
+bool PQValidate::validateLocationDatabase() {
+
+    // the db does not exist -> create it and finish
+    if(!QFile::exists(ConfigFiles::LOCATION_DB())) {
+        if(!QFile::copy(":/location.db", ConfigFiles::LOCATION_DB()))
+            LOG << CURDATE << "PQValidate::validateLocationDatabase(): unable to (re-)create default location database" << NL;
+        else {
+            QFile file(ConfigFiles::LOCATION_DB());
+            file.setPermissions(file.permissions()|QFileDevice::WriteOwner);
+        }
+    }
+
+    return true;
+
+}
