@@ -28,24 +28,66 @@ function checkComboForShortcut(combo, wheelDelta) {
         return
     }
 
-    if(combo == "Escape" && contextmenu.visible) {
+    if(combo == "Escape" && contextmenu.isOpen) {
         contextmenu.hideMenu()
         return
     }
 
-    whatToDoWithFoundShortcut(PQShortcuts.getCommandForShortcut(combo), wheelDelta)
+    if(combo == "Escape" && filefoldermodel.filterCurrentlyActive) {
+        loader.passOn("filter", "removeFilter", undefined)
+        return
+    }
+
+    var data = PQShortcuts.getCommandsForShortcut(combo)
+
+    if(data.length != 4)
+        return
+
+    var commands = data[0]
+    var cycle = data[1]*1
+    var cycletimeout = data[2]*1
+    var simultaneous = data[3]*1
+
+    if(simultaneous == 1) {
+
+        for(var c in commands) {
+            var cmd = commands[c]
+            if(cmd[0] == "_" && cmd[1] == "_")
+                executeInternalFunction(cmd, wheelDelta)
+            else {
+                if(filefoldermodel.countMainView == 0)
+                    return
+                var parts = cmd.split(":/:/:")
+                if(parts.length != 3)
+                    return
+                handlingExternal.executeExternal(parts[0], parts[1], filefoldermodel.currentFilePath)
+                if(parts[2]*1 === 1)
+                    toplevel.closePhotoQt()
+            }
+        }
+
+    } else {
+
+        var index = handlingShortcuts.getNextCommandInCycle(combo, cycletimeout, commands.length)
+        var cmd = commands[index]
+        if(cmd[0] == "_" && cmd[1] == "_")
+            executeInternalFunction(cmd, wheelDelta)
+        else {
+            if(filefoldermodel.countMainView == 0)
+                return
+            var parts = cmd.split(":/:/:")
+            if(parts.length != 3)
+                return
+            handlingExternal.executeExternal(parts[0], parts[1], filefoldermodel.currentFilePath)
+            if(parts[2]*1 === 1)
+                toplevel.closePhotoQt()
+        }
+
+    }
 
 }
 
-function executeInternalFunction(func, args) {
-    whatToDoWithFoundShortcut(["",func,args])
-}
-
-function whatToDoWithFoundShortcut(sh, wheelDelta) {
-
-    var close = sh[0]
-    var cmd = sh[1]
-    var args = sh[2]
+function executeInternalFunction(cmd, wheelDelta) {
 
     if(cmd === "__quit")
         toplevel.quitPhotoQt()
@@ -103,16 +145,29 @@ function whatToDoWithFoundShortcut(sh, wheelDelta) {
         loader.ensureItIsReady("copymove")
         loader.passOn("copymove", "move", undefined)
     } else if(cmd === "__deletePermanent") {
-        if(filefoldermodel.current != -1)
-            handlingFileDir.deleteFile(filefoldermodel.currentFilePath, true)
+        if(filefoldermodel.current != -1) {
+            // we use the unavailable element to show
+            if(handlingFileDir.deleteFile(filefoldermodel.currentFilePath, true)) {
+                loader.passOn("notification", "show", undefined)
+                notification.item.statustext = em.pty+qsTranslate("filemanagement", "File successfully deleted")
+            } else {
+                loader.passOn("notification", "show", undefined)
+                notification.item.statustext = em.pty+qsTranslate("filemanagement", "Could not delete file")
+            }
+        }
     } else if(cmd === "__deleteTrash") {
-        if(filefoldermodel.current != -1)
-            handlingFileDir.deleteFile(filefoldermodel.currentFilePath, false)
+        if(filefoldermodel.current != -1) {
+            if(handlingFileDir.deleteFile(filefoldermodel.currentFilePath, false)) {
+                passOn("unavailable", "show", undefined)
+                unavailable.item.statustext = em.pty+qsTranslate("filemanagement", "File successfully moved to trash")
+            } else {
+                passOn("unavailable", "show", undefined)
+                unavailable.item.statustext = em.pty+qsTranslate("filemanagement", "Could not move file to trash")
+            }
+        }
     } else if(cmd === "__saveAs")
         loader.show("filesaveas")
-    else if(cmd === "__showMetaData")
-        loader.metadataPassOn("toggle", undefined)
-    else if(cmd === "__keepMetaData")
+    else if(cmd === "__showMetaData" || cmd === "__keepMetaData")
         loader.metadataPassOn("toggleKeepOpen", undefined)
     else if(cmd === "__showMainMenu")
         loader.mainmenuPassOn("toggle", undefined)
@@ -175,10 +230,29 @@ function whatToDoWithFoundShortcut(sh, wheelDelta) {
                 PQSettings.interfaceTrayIcon = 1
             toplevel.closePhotoQt()
         }
-    } else {
-        handlingExternal.executeExternal(cmd, args, filefoldermodel.currentFilePath)
-        if(close === "1")
-            toplevel.closePhotoQt()
+    } else if(cmd == "__moveViewLeft")
+        imageitem.moveViewLeft()
+    else if(cmd == "__moveViewRight")
+        imageitem.moveViewRight()
+    else if(cmd == "__moveViewUp")
+        imageitem.moveViewUp()
+    else if(cmd == "__moveViewDown")
+        imageitem.moveViewDown()
+    else if(cmd == "__goToLeftEdge")
+        imageitem.goToLeftEdge()
+    else if(cmd == "__goToRightEdge")
+        imageitem.goToRightEdge()
+    else if(cmd == "__goToTopEdge")
+        imageitem.goToTopEdge()
+    else if(cmd == "__goToBottomEdge")
+        imageitem.goToBottomEdge()
+    else if(cmd == "__showMapCurrent") {
+        if(handlingGeneral.isLocationSupportEnabled()) {
+            loader.ensureItIsReady("mapcurrent")
+            PQSettings.mapviewCurrentVisible = !PQSettings.mapviewCurrentVisible
+        }
+    } else if(cmd == "__showMapExplorer") {
+        if(handlingGeneral.isLocationSupportEnabled())
+            loader.show("mapexplorer")
     }
-
 }
